title:      Proselint
desc:       Docnado Tooling Quick Reference
date:       2018/07/20
version:    1.0.0
template:   document
nav:        Tooling>Proselint
percent:    100
authors:    enq@heinventions.com

Try using [proselint](https://github.com/amperser/proselint) with your docnado project. Proselint is a linter for English prose. A linter is a program that, like a spell checker, scans through a document and analyses it.

```bash
$ cd ~/my_project
$ ls
docs  logo.png  style

$ proselint .\docs\
```
